Learn R Programming

sharpData (version 1.2)

LL.fit: Local linear Regression Estimation

Description

This computes the local linear regression estimator at a few gridpoints. For a large number of gridpoints, it is not efficient.

Usage

LL.fit(x, y, xgrid, h, kernel)

Arguments

x

numeric explanatory vector

y

numeric response vector

xgrid

numeric vector

h

numeric bandwidth

kernel

character constant

Value

a vector of predictor values

References

Wand and Jones, 1996, Kernel Smoothing, Chapman and Hall.

See Also

locpoly

Examples

Run this code
# NOT RUN {
x <- sort(runif(100))
y <- x + sin(x) + rnorm(100)*.1
LL.fit(x,y,c(.3, .5, .7),h=.5)
# }

Run the code above in your browser using DataLab