Learn R Programming

sharpData (version 1.2)

LLmat: Local Linear Regression Matrix

Description

This computes the smoother matrix for the monotonic local linear sharpening problem.

Usage

LLmat(xgrid, x,  h, kernel)

Arguments

xgrid

numeric vector

x

numeric explanatory vector

h

numeric bandwidth

kernel

character constant

Value

a list containing the A matrix and the number of rows in A.