This function computes the A matrix for use in quadprog. This matrix corresponds to the derivative matrix for constrained sharpening in the monotonic regression problem.
NWmat(xgrid, x, h, kernel = "biweight")a vector of gridpoints to evaluate estimate at
a vector containing the predictor data
a scalar bandwidth
a character string naming the kernel function
a matrix