powered by
This computes the local linear regression estimator at a few gridpoints. For a large number of gridpoints, it is not efficient.
LL.fit(x, y, xgrid, h, kernel)
numeric explanatory vector
numeric response vector
numeric vector
numeric bandwidth
character constant
a vector of predictor values
Wand and Jones, 1996, Kernel Smoothing, Chapman and Hall.
locpoly
# NOT RUN { x <- sort(runif(100)) y <- x + sin(x) + rnorm(100)*.1 LL.fit(x,y,c(.3, .5, .7),h=.5) # }
Run the code above in your browser using DataLab