LLmat: Local Linear Regression Matrix
Description
This computes the smoother matrix for the monotonic local linear sharpening problem.
Usage
LLmat(xgrid, x, h, kernel)
Arguments
x
numeric explanatory vector
Value
a list containing the A matrix and the number of rows in A.