The burnRate data frame contains laboratory data on the
proportion of remaining fuel in a piece of wood that has burned
for a fixed period of time subjected to a fixed windspeed.
Usage
data(burnRate)
Arguments
Format
This data frame contains the following columns:
proportionBurned
a numeric vector
densityRatio
ratio of windspeed, multiplied by density of air,
to density of firebrand